;
; ZX81DEF.INC
; include file with definitions and symbols used by Sinclair ZX81
; for FASMZ80 (flatassembler with Z80 instruction set)
;
; V1.0
; (C)opyright by Karl-Heinz Dahlmann, Mnchen
;

; this definitions should not be changed

	NO	EQU	0
	YES	EQU	1
	NEWLINE EQU	$76	; character for NEWLINE
	SPACE	EQU	0	; character for SPACE


define	MEM_1K	1024	; internal 1k RAM
	MEM_2K	EQU	2048	; internal 2k RAM
	MEM_4K	EQU	4096	; 4k RAM
	MEM_8K	EQU	8192	; 8k RAM
	MEM_16k EQU	16384	; external 16k RAM
	MEM_32k EQU	32768	; external 32k RAM
	MEM_48k EQU	49152	; external 48k RAM
	MEMST	EQU	16384	; begin of memory section of ZX81 (system variables)

; description of flag variable in ZX81
;       BIT 0   leading space in line, 0=permitted / 1=suppress
;       BIT 1   printer in use, 0=no / 1=yes
;       BIT 2   cursor mode, 0=K cursor / 1=L cursor
;       BIT 3
;       BIT 4
;       BIT 5
;       BIT 6   result type, 0=string / 1=numeric
;       BIT 7   syntax check, 0=check syntax only / 1=executing
;
	FLAG_SUPS EQU $01	; suppress space
	FLAG_PRIU EQU $02	; printer using
	FLAG_CURL EQU $04	; cursor L type
	FLAG_NUM  EQU $40	; numeric expression
	FLAG_EXEC EQU $80	; execution

; description of cursor type variable (MODE) in ZX81
;
	CURS_KL EQU $00
	CURS_F	EQU $01
	CURS_G	EQU $02

; margin value for ZX81 (55 for PAL, 50Hz / 31 for NTSC, 60Hz)
;
	MARGPAL  EQU 55
	MARGNTSC EQU 31

; compute and display flag in ZX81
;
;       BIT 0   keystroke, 0=NO / 1=YES
;       BIT 6   fast/slow mode, 0=fast mode / 1=slow mode
;       BIT 7   internal mode using now, 0=fast mode / 1=slow mode

	KEYSTROKE EQU $01
	SLOW_MODE EQU $40
	FAST_MODE EQU $00

; this definitions can be changed regarding hardware used
; change this definitions in source file before including ZX81VARS.INC
; (because changes affects contents of system variables)

; used memory option of ZX81, default minimum 1k
	MEMAVL	EQU	MEM_1K
; default value for FLAG variable
	DEFFLAG EQU	FLAG_EXEC OR FLAG_NUM
; used TV option of ZX81, default PAL
	MARGVAL EQU	MARGPAL
; compute and display flag
	DISPMOD EQU	SLOW_MODE

